Function csp_connect

pub unsafe extern "C" fn csp_connect(
    prio: u8,
    dst: u16,
    dst_port: u8,
    timeout: u32,
    opts: u32,
) -> *mut csp_conn_t
Establish outgoing connection. The call will return immediately, unless it is a RDP connection (#CSP_O_RDP) in which case it will wait until the other end acknowleges the connection (timeout is determined by the current connection timeout set by csp_rdp_set_opt()).

@param[in] prio priority, see #csp_prio_t @param[in] dst Destination address @param[in] dst_port Destination port @param[in] timeout unused. @param[in] opts connection options, see @ref CSP_CONNECTION_OPTIONS. @return Established connection or NULL on failure (no free connections, timeout).