Function csp_route_work

pub unsafe extern "C" fn csp_route_work() -> c_int
Route packet from the incoming router queue and check RDP timeouts. In order for incoming packets to routed and RDP timeouts to be checked, this function must be called reguarly. @return #CSP_ERR_NONE on success, otherwise an error code.